@@ -12,7 +12,7 @@ use cap_primitives::fs::{
     read_base_dir, read_dir, read_link, remove_dir, remove_dir_all, remove_file, remove_open_dir,
     remove_open_dir_all, rename, set_permissions, stat, DirOptions, FollowSymlinks, Permissions,
 };
-use cap_primitives::{ambient_authority, AmbientAuthority};
+use cap_primitives::AmbientAuthority;
 #[cfg(not(windows))]
 use io_lifetimes::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
 use io_lifetimes::{AsFilelike, FromFilelike};
@@ -54,12 +54,10 @@ impl Dir {
     /// To prevent race conditions on Windows, the file must be opened without
     /// `FILE_SHARE_DELETE`.
     ///
-    /// # Ambient Authority
-    ///
-    /// `async_std::fs::File` is not sandboxed and may access any path that the
-    /// host process has access to.
+    /// This grants access the resources the `async_std::fs::File` instance
+    /// already has access to.
     #[inline]
-    pub fn from_std_file(std_file: fs::File, _: AmbientAuthority) -> Self {
+    pub fn from_std_file(std_file: fs::File) -> Self {
         Self { std_file }
     }
 
@@ -107,7 +105,7 @@ impl Dir {
         })
         .await?
         .into();
-        Ok(File::from_std(file, ambient_authority()))
+        Ok(File::from_std(file))
     }
 
     #[cfg(target_os = "wasi")]
@@ -117,7 +115,7 @@ impl Dir {
         options: &OpenOptions,
     ) -> io::Result<File> {
         let file = options.open_at(&self.std_file, path)?.into();
-        Ok(File::from_std(file, ambient_authority()))
+        Ok(File::from_std(file))
     }
 
     /// Attempts to open a directory.
@@ -130,7 +128,7 @@ impl Dir {
         })
         .await?
         .into();
-        Ok(Self::from_std_file(dir, ambient_authority()))
+        Ok(Self::from_std_file(dir))
     }
 
     /// Creates a new, empty directory at the provided path.
@@ -772,7 +770,7 @@ impl Dir {
         let path = path.as_ref().to_path_buf();
         spawn_blocking(move || open_ambient_dir(path.as_ref(), ambient_authority))
             .await
-            .map(|f| Self::from_std_file(f.into(), ambient_authority))
+            .map(|f| Self::from_std_file(f.into()))
     }
 
     /// Constructs a new instance of `Self` by opening the parent directory
@@ -792,7 +790,7 @@ impl Dir {
         })
         .await?
         .into();
-        Ok(Self::from_std_file(dir, ambient_authority))
+        Ok(Self::from_std_file(dir))
     }
 
     /// Recursively create a directory and all of its parent components if they
@@ -817,7 +815,7 @@ impl Dir {
 impl FromRawFd for Dir {
     #[inline]
     unsafe fn from_raw_fd(fd: RawFd) -> Self {
-        Self::from_std_file(fs::File::from_raw_fd(fd), ambient_authority())
+        Self::from_std_file(fs::File::from_raw_fd(fd))
     }
 }
 
@@ -825,7 +823,7 @@ impl FromRawFd for Dir {
 impl FromFd for Dir {
     #[inline]
     fn from_fd(fd: OwnedFd) -> Self {
-        Self::from_std_file(fs::File::from_fd(fd), ambient_authority())
+        Self::from_std_file(fs::File::from_fd(fd))
     }
 }
 
@@ -835,7 +833,7 @@ impl FromRawHandle for Dir {
     /// without `FILE_SHARE_DELETE`.
     #[inline]
     unsafe fn from_raw_handle(handle: RawHandle) -> Self {
-        Self::from_std_file(fs::File::from_raw_handle(handle), ambient_authority())
+        Self::from_std_file(fs::File::from_raw_handle(handle))
     }
 }
 
@@ -843,7 +841,7 @@ impl FromRawHandle for Dir {
 impl FromHandle for Dir {
     #[inline]
     fn from_handle(handle: OwnedHandle) -> Self {
-        Self::from_std_file(fs::File::from_handle(handle), ambient_authority())
+        Self::from_std_file(fs::File::from_handle(handle))
     }
 }
 
