@@ -3,7 +3,6 @@ use crate::os::unix::net::SocketAddr;
 use async_std::io;
 use async_std::os::unix;
 use async_std::os::unix::io::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
-use cap_primitives::{ambient_authority, AmbientAuthority};
 use io_lifetimes::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
 use std::fmt;
 
@@ -32,12 +31,11 @@ impl UnixDatagram {
     /// Constructs a new instance of `Self` from the given
     /// `async_std::os::unix::net::UnixDatagram`.
     ///
-    /// # Ambient Authority
-    ///
-    /// `async_std::os::unix::net::UnixDatagram` is not sandboxed and may
-    /// access any address that the host process has access to.
+    /// This grants access the resources the
+    /// `async_std::os::unix::net::UnixDatagram` instance already has access
+    /// to.
     #[inline]
-    pub fn from_std(std: unix::net::UnixDatagram, _: AmbientAuthority) -> Self {
+    pub fn from_std(std: unix::net::UnixDatagram) -> Self {
         Self { std }
     }
 
@@ -52,7 +50,7 @@ impl UnixDatagram {
     #[inline]
     pub fn unbound() -> io::Result<Self> {
         let unix_datagram = unix::net::UnixDatagram::unbound()?;
-        Ok(Self::from_std(unix_datagram, ambient_authority()))
+        Ok(Self::from_std(unix_datagram))
     }
 
     /// Creates an unnamed pair of connected sockets.
@@ -64,12 +62,7 @@ impl UnixDatagram {
     /// [`async_std::os::unix::net::UnixDatagram::pair`]: https://docs.rs/async-std/latest/async_std/os/unix/net/struct.UnixDatagram.html#method.pair
     #[inline]
     pub fn pair() -> io::Result<(Self, Self)> {
-        unix::net::UnixDatagram::pair().map(|(a, b)| {
-            (
-                Self::from_std(a, ambient_authority()),
-                Self::from_std(b, ambient_authority()),
-            )
-        })
+        unix::net::UnixDatagram::pair().map(|(a, b)| (Self::from_std(a), Self::from_std(b)))
     }
 
     // async_std doesn't have `try_clone`.
@@ -154,17 +147,14 @@ impl UnixDatagram {
 impl FromRawFd for UnixDatagram {
     #[inline]
     unsafe fn from_raw_fd(fd: RawFd) -> Self {
-        Self::from_std(
-            unix::net::UnixDatagram::from_raw_fd(fd),
-            ambient_authority(),
-        )
+        Self::from_std(unix::net::UnixDatagram::from_raw_fd(fd))
     }
 }
 
 impl FromFd for UnixDatagram {
     #[inline]
     fn from_fd(fd: OwnedFd) -> Self {
-        Self::from_std(unix::net::UnixDatagram::from_fd(fd), ambient_authority())
+        Self::from_std(unix::net::UnixDatagram::from_fd(fd))
     }
 }
 
